Package: puremoe
Type: Package
Title: Pubmed Unified REtrieval for Multi-Output Exploration
Version: 1.0.4
Authors@R: c(person("Jason", "Timm", role = c("aut", "cre"), email = "JaTimm@salud.unm.edu"))
Maintainer: Jason Timm <JaTimm@salud.unm.edu>
Description: Access a variety of 'PubMed' data through a single, user-friendly interface, including abstracts, bibliometrics from 'iCite', pubtations from 'PubTator3', and full-text records from 'PMC'.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
Depends: R (>= 3.5)
Imports: rentrez, textshape, xml2, data.table, httr, pbapply, jsonlite,
        rappdirs
Suggests: knitr, rmarkdown, DT, dplyr
VignetteBuilder: knitr
RoxygenNote: 7.3.3
URL: https://github.com/jaytimm/puremoe,
        https://jaytimm.github.io/puremoe/
BugReports: https://github.com/jaytimm/puremoe/issues
NeedsCompilation: no
Packaged: 2026-04-21 16:31:24 UTC; jtimm
Author: Jason Timm [aut, cre]
Repository: CRAN
Date/Publication: 2026-04-21 17:02:08 UTC
Built: R 4.6.0; ; 2026-04-26 09:39:52 UTC; unix
